Learn R Programming

postcard (version 1.1.0)

postcard-package: postcard: Estimating Marginal Effects with Prognostic Covariate Adjustment

Description

logo

Conduct power analyses and inference of marginal effects. Uses plug-in estimation and influence functions to perform robust inference, optionally leveraging historical data to increase precision with prognostic covariate adjustment. The methods are described in Højbjerre-Frandsen et al. (2025) tools:::Rd_expr_doi("10.48550/arXiv.2503.22284").

Arguments

Author

Maintainer: Mathias Lerbech Jeppesen mathiasljeppesen@outlook.com

Authors:

Other contributors:

  • Novo Nordisk A/S [copyright holder]

See Also