- formula
an object of class "formula" (or one that can be coerced to that class):
a symbolic description of the model to be fitted. The details of model specification are
given under ‘Details’ in the glm documentation.
- exposure_indicator
(name of) the binary variable in data that
identifies randomisation groups. The variable is required to be binary currently.
- exposure_prob
a numeric with the probability of being in
"group 1" (rather than group 0) in groups defined by exposure_indicator.
- data
an optional data frame, list or environment (or object coercible
by as.data.frame to a data frame) containing the variables in the model. If
not found in data, the variables are taken from environment(formula), typically
the environment from which the function is called.
- family
a description of the error distribution and link
function to be used in the model. For glm this can be a
character string naming a family function, a family function or the
result of a call to a family function. For glm.fit only the
third option is supported. (See family for details of
family functions.)
- estimand_fun
a function with arguments psi1 and psi0 specifying
the estimand. Alternative, specify "ate" or "rate_ratio" as a character
to use one of the default estimand functions. See
more details in the "Estimand" section of rctglm.
- estimand_fun_deriv0
a function specifying the derivative of estimand_fun wrt. psi0. As a default
the algorithm will use symbolic differentiation to automatically find the derivative from estimand_fun
- estimand_fun_deriv1
a function specifying the derivative of estimand_fun wrt. psi1. As a default
the algorithm will use symbolic differentiation to automatically find the derivative from estimand_fun
- cv_variance
a logical determining whether to estimate the variance
using cross-validation (see details of rctglm).
- cv_variance_folds
a numeric with the number of folds to use for cross
validation if cv_variance is TRUE.
- ...
Additional arguments passed to stats::glm()
- data_hist
a data.frame with historical data on which to fit a prognostic model
- prog_formula
an object of class "formula" (or one that can be coerced to that class):
a symbolic description of the prognostic model to be fitted to data_hist. Passed in a
list as the preproc argument in fit_best_learner(). As a default,
the formula is created by modelling the response (assumed to have the same name as in
formula) using all columns in data_hist.
- cv_prog_folds
a numeric with the number of cross-validation folds used when fitting and
evaluating models
- learners
a list (preferably named) containing named lists of elements
model and optionally grid. The model element should be a parsnip
model specification, which is passed to workflowsets::workflow_set as the
model argument, while the grid element is passed as the grid argument
of workflowsets::option_add
- verbose
numeric verbosity level. Higher values means more information is
printed in console. A value of 0 means nothing is printed to console during
execution (Defaults to 2, overwritable using option 'postcard.verbose' or environment variable 'R_POSTCARD_VERBOSE')